@@ -1,4 +1,4 @@
-// test that parse(stringify(obj) deepEqu
+// test that parse(stringify(obj)
 
 var ini = require('../')
 var test = require('tap').test
@@ -10,11 +10,11 @@ var data = {
   'nested boolean': {theDude: {abides: true, rugCount: 1}},
 }
 
-test('parse(stringify(x)) deepEqual x', function (t) {
+test('parse(stringify(x)) is same as x', function (t) {
   for (var k in data) {
     var s = ini.stringify(data[k])
     t.comment(s, data[k])
-    t.deepEqual(ini.parse(s), data[k])
+    t.same(ini.parse(s), data[k])
   }
 
   t.end()
